@@ -21,6 +21,16 @@
 #endif
 #include "zoom.h"
 
+/* Maximum zoom factor */
+#define MAX_ZOOM_FACTOR 20
+#define MIN_ZOOM_FACTOR 0.02
+
+/* Default increment for zooming.  The current zoom factor is multiplied or
+ * divided by this amount on every zooming step.  For consistency, you should
+ * use the same value elsewhere in the program.
+ */
+#define IMAGE_VIEW_ZOOM_MULTIPLIER 1.05
+
 /* Maximum size of delayed repaint rectangles */
 #define PAINT_RECT_WIDTH 128
 #define PAINT_RECT_HEIGHT 128
@@ -2706,7 +2716,7 @@ _set_overlay_timeout (EogScrollView *view)
 
 	_clear_overlay_timeout (view);
 
-	source = g_timeout_source_new_seconds (2);
+	source = g_timeout_source_new (1000);
 	g_source_set_callback (source, _overlay_timeout_cb, view, NULL);
 
 	g_source_attach (source, NULL);
@@ -2911,6 +2921,7 @@ eog_scroll_view_init (EogScrollView *view)
 	gtk_widget_set_halign (priv->left_revealer, GTK_ALIGN_START);
 	gtk_widget_set_valign (priv->left_revealer, GTK_ALIGN_CENTER);
 	gtk_widget_set_margin_start(priv->left_revealer, 12);
+	gtk_widget_set_margin_end(priv->left_revealer, 12);
 	gtk_overlay_add_overlay (GTK_OVERLAY (priv->overlay),
 				 priv->left_revealer);
 
@@ -2922,6 +2933,7 @@ eog_scroll_view_init (EogScrollView *view)
 					      OVERLAY_REVEAL_ANIM_TIME);
 	gtk_widget_set_halign (priv->right_revealer, GTK_ALIGN_END);
 	gtk_widget_set_valign (priv->right_revealer, GTK_ALIGN_CENTER);
+	gtk_widget_set_margin_start (priv->right_revealer, 12);
 	gtk_widget_set_margin_end (priv->right_revealer, 12);
 	gtk_overlay_add_overlay(GTK_OVERLAY (priv->overlay),
 				priv->right_revealer);
